from fastapi import APIRouter, HTTPException, status
from schemas.contact_form import ContactFormCreate, ContactFormSchema
from helpers.contact_form_helpers import validate_contact_form_data, create_contact_form
from sqlalchemy.orm import Session
from fastapi import Depends
from core.database import get_db

router = APIRouter()

@router.post("/contact", status_code=status.HTTP_201_CREATED, response_model=ContactFormSchema)
async def create_contact(
    contact_data: ContactFormCreate,
    db: Session = Depends(get_db)
):
    if not validate_contact_form_data(contact_data):
        raise HTTPException(status_code=status.HTTP_400_BAD_REQUEST, detail="Invalid contact form data")

    new_contact = create_contact_form(db=db, contact_form_data=contact_data)
    return new_contact